package com.datacloudsec.response;

import com.datacloudsec.utils.JsonUtil;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_datacloudsec_response.jar:com/datacloudsec/response/TreegridResponse.class */
public class TreegridResponse extends JsonResponse {
    public TreegridResponse(List<Map<String, Object>> data, String parentFieldName, String... parentKey) {
        this(data.size(), data, parentFieldName, parentKey);
    }

    public TreegridResponse(int total, List<Map<String, Object>> data, String parentFieldName, String... parentKey) {
        super(true);
        super.putObj("total", Integer.valueOf(total));
        super.putObj("rows", createChilds(data, parentKey, 0, parentFieldName));
    }

    private static List<Map<String, Object>> createChilds(List<Map<String, Object>> data, String[] parentKey, int parentKeyIndex, String parentFieldName) {
        List<Map<String, Object>> newData = new ArrayList<>();
        while (data.size() > 0) {
            Map<String, Object> row = data.get(0);
            String type = (String) row.get(parentKey[parentKeyIndex]);
            if (StringUtils.isBlank(type)) {
                newData.add(row);
                data.remove(0);
            } else {
                List<Map<String, Object>> childs = findChilds(data, parentKey, parentKeyIndex, type, parentFieldName);
                Map<String, Object> map = new HashMap<>();
                map.put(parentFieldName, type);
                map.put("childs", childs);
                newData.add(map);
            }
        }
        return newData;
    }

    private static List<Map<String, Object>> findChilds(List<Map<String, Object>> data, String[] parentKey, int parentKeyIndex, String parentText, String parentFieldName) {
        if (parentKeyIndex >= parentKey.length) {
            return null;
        }
        List<Map<String, Object>> childs = new ArrayList<>();
        Iterator<Map<String, Object>> ite = data.iterator();
        while (ite.hasNext()) {
            Map<String, Object> row = ite.next();
            String type = (String) row.get(parentKey[parentKeyIndex]);
            if (type != null && type.equalsIgnoreCase(parentText)) {
                childs.add(row);
                ite.remove();
            }
        }
        if (parentKeyIndex + 1 >= parentKey.length) {
            return childs;
        }
        return createChilds(childs, parentKey, parentKeyIndex + 1, parentFieldName);
    }

    public static void main(String[] args) throws Exception {
        List<Map<String, Object>> data = new ArrayList<>();
        data.add(new HashMap<String, Object>() { // from class: com.datacloudsec.response.TreegridResponse.1
            private static final long serialVersionUID = 1;

            {
                put("add1", "四川");
                put("add2", "遂宁");
                put("add3", "蓬溪");
                put("name", "aaaaaaaaaa");
            }
        });
        data.add(new HashMap<String, Object>() { // from class: com.datacloudsec.response.TreegridResponse.2
            private static final long serialVersionUID = 1;

            {
                put("add1", "四川");
                put("add2", "遂宁");
                put("add3", "蓬溪");
                put("name", "bbbbbbb");
            }
        });
        data.add(new HashMap<String, Object>() { // from class: com.datacloudsec.response.TreegridResponse.3
            private static final long serialVersionUID = 1;

            {
                put("add1", "四川");
                put("add2", "遂宁");
                put("name", "cccc");
            }
        });
        data.add(new HashMap<String, Object>() { // from class: com.datacloudsec.response.TreegridResponse.4
            private static final long serialVersionUID = 1;

            {
                put("add1", "浙江");
                put("name", "ddddd");
            }
        });
        data.add(new HashMap<String, Object>() { // from class: com.datacloudsec.response.TreegridResponse.5
            private static final long serialVersionUID = 1;

            {
                put("name", "eeeee");
            }
        });
        String[] parentKey = {"add1", "add2", "add3"};
        List<Map<String, Object>> newData = createChilds(data, parentKey, 0, "name");
        System.out.println(JsonUtil.MAPPER.writeValueAsString(newData));
    }
}
